edx-bulk-grades
=============================

|pypi-badge| |travis-badge| |codecov-badge| |doc-badge| |pyversions-badge|
|license-badge|

Support for bulk scoring and grading. This adds models and an API for reading and modifying
scores and grades in bulk.

Overview (please modify)
------------------------

The ``README.rst`` file should then provide an overview of the code in this
repository, including the main components and useful entry points for starting
to understand the code in more detail.

Documentation
-------------

The full documentation is at https://edx-bulk-grades.readthedocs.org.

License
-------

The code in this repository is licensed under the AGPL 3.0 unless
otherwise noted.

Please see ``LICENSE.txt`` for details.

How To Contribute
-----------------

Contributions are very welcome.

Please read `How To Contribute <https://github.com/edx/edx-platform/blob/master/CONTRIBUTING.rst>`_ for details.

Even though they were written with ``edx-platform`` in mind, the guidelines
should be followed for Open edX code in general.

The pull request description template should be automatically applied if you are creating a pull request from GitHub. Otherwise you
can find it at `PULL_REQUEST_TEMPLATE.md <https://github.com/edx/edx-bulk-grades/blob/master/.github/PULL_REQUEST_TEMPLATE.md>`_.

The issue report template should be automatically applied if you are creating an issue on GitHub as well. Otherwise you
can find it at `ISSUE_TEMPLATE.md <https://github.com/edx/edx-bulk-grades/blob/master/.github/ISSUE_TEMPLATE.md>`_.

Reporting Security Issues
-------------------------

Please do not report security issues in public. Please email security@edx.org.

Getting Help
------------

Have a question about this repository, or about Open edX in general?  Please
refer to this `list of resources`_ if you need any assistance.

.. _list of resources: https://open.edx.org/getting-help


.. |pypi-badge| image:: https://img.shields.io/pypi/v/edx-bulk-grades.svg
    :target: https://pypi.python.org/pypi/edx-bulk-grades/
    :alt: PyPI

.. |travis-badge| image:: https://travis-ci.org/edx/edx-bulk-grades.svg?branch=master
    :target: https://travis-ci.org/edx/edx-bulk-grades
    :alt: Travis

.. |codecov-badge| image:: http://codecov.io/github/edx/edx-bulk-grades/coverage.svg?branch=master
    :target: http://codecov.io/github/edx/edx-bulk-grades?branch=master
    :alt: Codecov

.. |doc-badge| image:: https://readthedocs.org/projects/edx-bulk-grades/badge/?version=latest
    :target: http://edx-bulk-grades.readthedocs.io/en/latest/
    :alt: Documentation

.. |pyversions-badge| image:: https://img.shields.io/pypi/pyversions/edx-bulk-grades.svg
    :target: https://pypi.python.org/pypi/edx-bulk-grades/
    :alt: Supported Python versions

.. |license-badge| image:: https://img.shields.io/github/license/edx/edx-bulk-grades.svg
    :target: https://github.com/edx/edx-bulk-grades/blob/master/LICENSE.txt
    :alt: License
